#!/usr/bin/make -f
# 							-*- makefile -*-
#
# Generic debian/rules file for the Debian/GNU Linux r-cran-* packages
#
# Should be sufficient for Debianization of CRAN (http://cran.r-project.org) 
# packages. Note that you still need to provide the other files in debian/*,
# in particular control, changelog and copyright. 
# 
# Copyright 2003-2007 by Dirk Eddelbuettel <edd@debian.org>

include /usr/share/cdbs/1/rules/debhelper.mk
include /usr/share/cdbs/1/class/langcore.mk
include /usr/share/cdbs/1/rules/dpatch.mk

# awk command to extract word after Package or Bundle, lowercased
awkString	:= "'/^(Package|Bundle):/ {print tolower($$2) }'"

# apply it to the upstream meta-info file DESCRIPTION
cranName        := $(shell awk "$(awkString)" DESCRIPTION)

## if no debRreposname is known, set default to cran -- thanks, Steffen!
ifeq ($(debRreposname),)
  debRreposname	:= cran
endif

## we can define additional flags for R's make, eg "CXXFLAGS=-g0" for 
## RQuantLib but the default is empty
##   makeFlags	:=
## if makeFlags are defined, then we'll use them in this variable
## which would otherwise be empty
ifneq ($(makeFlags),)
  makeFlagsCall	:= MAKEFLAGS=$(makeFlags)
endif

## and use the results to build the Debian'ized package name
package		:= r-$(debRreposname)-$(cranName)

## awk command to extract word after Priority
prioritystr	:= "'/^Priority:/ {print tolower($$2) }'"
priority        := $(shell awk "$(prioritystr)" DESCRIPTION)

ifeq ($(priority),recommended)
  debRdir	:= usr/lib/R/library
else
  debRdir	:= usr/lib/R/site-library
endif

## we use these results for the to-be-installed-in directory
debRlib		:= $(CURDIR)/debian/$(package)/$(debRdir)

## optional installation of a lintian silencer
lintiandir	:= $(CURDIR)/debian/$(package)/usr/share/lintian/overrides

common-install-indep:: R_any_arch
common-install-arch:: R_any_arch

R_any_arch:
                ## create the target directory
		dh_installdirs		$(debRdir)
                ##
                ## if we find /usr/bin/java, reconfigure R for Java
		#if test -f /usr/bin/java; then 				\
		#	R CMD javareconf -e '';				\
		#fi	
                ## call R to install the sources we're looking at
                ## use this inside xvfb-run if this wrapper is installed
		if test -f /usr/bin/xvfb-run; then 			\
			$(makeFlagsCall) xvfb-run 			\
				R CMD INSTALL -l $(debRlib) --clean     \
					$(extraInstallFlags) . ;	\
		else							\
			$(makeFlagsCall) R CMD INSTALL -l $(debRlib) 	\
					--clean $(extraInstallFlags) . ;\
		fi
                ## remove extra files which are present in some packages
		rm -vf $(debRlib)/R.css 			\
			$(debRlib)/$(cranName)/COPYING 		\
			$(debRlib)/$(cranName)/LICENSE.txt
                ## if we have an overrides file for lintian, install it
		if test -f debian/overrides; then 		\
			install -d $(lintiandir) ; 		\
			install -m 0644 debian/overrides 	\
				$(lintiandir)/$(package); 	\
		fi
